@@ -21,36 +21,24 @@ fi
 
 tscriptname=`basename $0 .sh`
 export PKG=`echo $tscriptname | sed -e 's/\-[^\-]*\-[^\-]*$//'`
-export PKG2=libpng12
-export PKG3=libpng12-devel
-export VER=`echo $tscriptname | sed -e "s/${PKG}\-//" -e 's/\-[^\-]*$//'`
-export REL=`echo $tscriptname | sed -e "s/${PKG}\-${VER}\-//"`
+export PKG2=libpng2
+export VER=`echo $tscriptname | sed -e 's/^[^\-]*\-//' -e 's/\-[^\-]*$//'`
+export REL=`echo $tscriptname | sed -e 's/^[^\-]*\-[^\-]*\-//'`
 export FULLPKG=${PKG}-${VER}-${REL}
 export FULLPKG2=${PKG2}-${VER}-${REL}
-export FULLPKG3=${PKG3}-${VER}-${REL}
-
-# determine correct decompression option and tarball filename
-if [ -e ${PKG}-${VER}.tar.gz ] ; then
-  export opt_decomp=z
-  export src_orig_pkg_ext=gz
-elif [ -e ${PKG}-${VER}.tar.bz2 ] ; then
-  export opt_decomp=j
-  export src_orig_pkg_ext=bz2
-fi
-
-export src_orig_pkg_name=${PKG}-${VER}.tar.${src_orig_pkg_ext}
+export src_orig_pkg_name=${PKG}-${VER}.tar.gz
 export src_pkg_name=${FULLPKG}-src.tar.bz2
+export src_pkg_name2=${FULLPKG2}-src.tar.bz2
 export src_patch_name=${FULLPKG}.patch
 export bin_pkg_name=${FULLPKG}.tar.bz2
 export bin_pkg_name2=${FULLPKG2}.tar.bz2
-export bin_pkg_name3=${FULLPKG3}.tar.bz2
 
 export src_orig_pkg=${topdir}/${src_orig_pkg_name}
 export src_pkg=${topdir}/${src_pkg_name}
+export src_pkg2=${topdir}/${src_pkg_name2}
 export src_patch=${topdir}/${src_patch_name}
 export bin_pkg=${topdir}/${bin_pkg_name}
 export bin_pkg2=${topdir}/${bin_pkg_name2}
-export bin_pkg3=${topdir}/${bin_pkg_name3}
 export srcdir=${topdir}/${PKG}-${VER}
 export objdir=${srcdir}/.build
 export instdir=${srcdir}/.inst
@@ -61,140 +49,120 @@ host=i686-pc-cygwin
 # if this package creates binaries, they run on
 target=i686-pc-cygwin
 prefix=/usr
-pnoslash=`echo $prefix | sed -e 's#^/##'`
 sysconfdir=/etc
-snoslash=`echo $sysconfdir | sed -e 's#^/##'`
 
 mkdirs() {
   (cd ${topdir} && \
-  rm -fr ${objdir} ${instdir} ${srcinstdir} && \
   mkdir -p ${objdir} && \
   mkdir -p ${instdir} && \
-  mkdir -p ${srcinstdir}
-)}
-
+  mkdir -p ${srcinstdir} )
+}
 prep() {
   (cd ${topdir} && \
-  tar xv${opt_decomp}f ${src_orig_pkg} ; \
+  tar xvzf ${src_orig_pkg} ; \
   cd ${topdir} && \
   patch -p0 < ${src_patch} 
   && mkdirs && \
+  cd ${srcdir} && \
+  for fn in *; do \
+    if [ -f ${fn} ] ; then \
+      cp ${fn} ${objdir} ;\
+    fi;\
+  done && \
+  if [ ! -d ${objdir}/projects/msvc ] ; then\
+    mkdir -p ${objdir}/projects/msvc ;\
+  fi;\
+  if [ -f ${srcdir}/projects/msvc/png32ms.def ] ; then\
+    cp ${srcdir}/projects/msvc/png32ms.def ${objdir}/projects/msvc/png32ms.def ;\
+  fi;\
   if [ -f ${srcdir}/scripts/makefile.cygwin ] ; then \
     cp ${srcdir}/scripts/makefile.cygwin ${objdir}/Makefile ;\
-  fi
-)}
-
+  fi ) 
+}
 conf() {
   echo Configuration successful.
 }
-
 build() {
   (cd ${objdir} && \
-  make SRCDIR=${srcdir} prefix=${prefix}
-)}
-
+  make )
+}
 check() {
   (cd ${objdir} && \
-  make test SRCDIR=${srcdir} prefix=${prefix} | tee ${checkfile} 2>&1
-)}
-
+  make test | tee ${checkfile} 2>&1 )
+}
 clean() {
   (cd ${objdir} && \
-  make clean SRCDIR=${srcdir} prefix=${prefix}
-)}
-
+  make clean )
+}
 install() {
   (cd ${objdir} && \
-  make install DESTDIR=${instdir} SRCDIR=${srcdir} prefix=${prefix}
-  for fn in ${prefix}/info/dir ${prefix}/bin/libpng-config \
-    ${prefix}/lib/libpng.a ${prefix}/lib/libpng.dll.a \
-    ${prefix}/include/libpng ${prefix}/lib/pkgconfig/libpng.pc \
-    ${prefix}/include/pngconf.h ${prefix}/include/png.h ; do \
-	 if [ -e ${instdir}${fn} ] ; then \
-      rm -f ${instdir}${fn} ; \
-    fi ;\
-  done && \
-  for dirn in ${prefix}/share/doc/${PKG}-${VER} ${prefix}/share/doc/${PKG3}-${VER} \
-    ${prefix}/share/doc/Cygwin ${sysconfdir}/postinstall ; do \
-    if [ ! -d ${instdir}${dirn} ]; then \
-      mkdir -p ${instdir}${dirn} ; \
-    fi ;\
-  done && \
+  make install prefix=${instdir}${prefix} 
+  if [ -f ${instdir}${prefix}/info/dir ] ; then \
+    rm ${instdir}${prefix}/info/dir ; \
+  fi && \
+  if [ ! -d ${instdir}${prefix}/doc/${PKG}-${VER} ]; then \
+    mkdir -p ${instdir}${prefix}/doc/${PKG}-${VER} ; \
+  fi && \
+  if [ ! -d ${instdir}${prefix}/doc/Cygwin ]; then \
+    mkdir -p ${instdir}${prefix}/doc/Cygwin ; \
+  fi && \
   templist=""; \
   for f in ${srcdir}/ANNOUNCE ${srcdir}/CHANGES ${srcdir}/INSTALL \
            ${srcdir}/KNOWNBUG ${srcdir}/LICENSE ${srcdir}/README \
-           ${srcdir}/TODO ${srcdir}/Y2KINFO ${srcdir}/example.c ; do \
+			  ${srcdir}/TODO ${srcdir}/Y2KINFO ; do \
     if [ -f $f ] ; then \
       templist="$templist $f"; \
     fi ; \
   done && \
   if [ ! "x$templist" = "x" ]; then \
     /usr/bin/install -m 644 $templist \
-         ${instdir}${prefix}/share/doc/${PKG}-${VER} ;
-    /usr/bin/install -m 644 $templist \
-         ${instdir}${prefix}/share/doc/${PKG3}-${VER} ;
+         ${instdir}${prefix}/doc/${PKG}-${VER} ;
   fi && \
-  cat ${srcdir}/CYGWIN-PATCHES/${PKG}.frag \
-    ${srcdir}/CYGWIN-PATCHES/README.frag > \
-    ${instdir}${prefix}/share/doc/Cygwin/${PKG}-${VER}.README && \
-  cat ${srcdir}/CYGWIN-PATCHES/${PKG3}.frag \
-    ${srcdir}/CYGWIN-PATCHES/README.frag > \
-    ${instdir}${prefix}/share/doc/Cygwin/${PKG3}-${VER}.README && \
-  /usr/bin/install -m 755 ${srcdir}/CYGWIN-PATCHES/postinstall.sh \
-    ${instdir}${sysconfdir}/postinstall/${PKG3}.sh
-)}
-
+  if [ -f ${srcdir}/CYGWIN-PATCHES/${PKG}.README ]; then \
+    /usr/bin/install -m 644 ${srcdir}/CYGWIN-PATCHES/${PKG}.README \
+      ${instdir}${prefix}/doc/Cygwin/${PKG}-${VER}.README ; \
+  else \
+    if [ -f ${srcdir}/CYGWIN-PATCHES/README ]; then \
+      /usr/bin/install -m 644 ${srcdir}/CYGWIN-PATCHES/README \
+        ${instdir}${prefix}/doc/Cygwin/${PKG}-${VER}.README ; \
+    fi ;\
+  fi )
+}
 strip() {
   (cd ${instdir} && \
-  find . -name "*.dll" | xargs strip > /dev/null 2>&1 
-  find . -name "*.exe" | xargs strip > /dev/null 2>&1 
-  /bin/true
-)}
-
+  find . -name "*.dll" | xargs strip )
+}
 pkg() {
   (cd ${instdir} && \
-  tar cvjf ${bin_pkg} --exclude="${pnoslash}/bin" \
-    --exclude="${pnoslash}/include" \
-    --exclude="${pnoslash}/lib" \
-    --exclude="${snoslash}/postinstall" \
-    --exclude="${pnoslash}/share/doc/${PKG3}*" \
-    --exclude="${pnoslash}/share/doc/Cygwin/${PKG3}*" \
-    * ; 
-  tar cvjf ${bin_pkg2} ${pnoslash}/bin/*.dll ;
-  tar cvjf ${bin_pkg3} --exclude="${pnoslash}/bin/*.dll" \
-    ${pnoslash}/bin \
-    ${pnoslash}/include \
-    ${pnoslash}/lib \
-    ${snoslash}/postinstall \
-    ${pnoslash}/share/doc/${PKG3}* \
-    ${pnoslash}/share/doc/Cygwin/${PKG3}*
-)}
-
+  tar cvjf ${bin_pkg2} usr/bin/*.dll ;\
+  tar cvjf ${bin_pkg} --exclude='usr/bin/*.dll' * )
+}
 mkpatch() {
   (cd ${srcdir} && \
-  tar xv${opt_decomp}f ${src_orig_pkg} ;\
+  tar xvzf ${src_orig_pkg} ;\
   mv ${PKG}-${VER} ../${PKG}-${VER}-orig && \
   cd ${topdir} && \
   diff -urN -x '.build' -x '.inst' -x '.sinst' \
     ${PKG}-${VER}-orig ${PKG}-${VER} > \
     ${srcinstdir}/${src_patch_name} ; \
-  rm -rf ${PKG}-${VER}-orig
-)}
-
+  rm -rf ${PKG}-${VER}-orig )
+}
 spkg() {
   (mkpatch && \
   cp ${src_orig_pkg} ${srcinstdir}/${src_orig_pkg_name} && \
   cp $0 ${srcinstdir}/`basename $0` && \
   cd ${srcinstdir} && \
-  tar cvjf ${src_pkg} *
-)}
-
+  tar cvjf ${src_pkg} * && \
+  cd ${srcdir}/CYGWIN-PATCHES && \
+  cp -a libpng2-src ${FULLPKG2} && \
+  tar cvjf ${src_pkg2} ${FULLPKG2} && \
+  rm -rf ${FULLPKG2} )
+}
 finish() {
   rm -rf ${srcdir} 
 }
 case $1 in
   prep)	prep ; STATUS=$? ;;
-  mkdirs)	mkdirs; STATUS=$? ;;
   conf)	conf ; STATUS=$? ;;
   build)	build ; STATUS=$? ;;
   check)	check ; STATUS=$? ;;
